==> apache-pinot-1.0.0-src.tar.gz: apache-pinot-1.0.0-src/pinot-core/src/main/java/org/apache/pinot/core/segment/processing/reducer/ReducerFactory.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pinot.core.segment.processing.reducer;

import java.io.File;
import org.apache.pinot.core.segment.processing.framework.MergeType;
import org.apache.pinot.core.segment.processing.framework.SegmentProcessorConfig;
import org.apache.pinot.core.segment.processing.genericrow.GenericRowFileManager;


/**
 * Factory for Reducer.
 */
public class ReducerFactory {
  private ReducerFactory() {
  }

  public static Reducer getReducer(String partitionId, GenericRowFileManager fileManager,
      SegmentProcessorConfig processorConfig, File reducerOutputDir) {
    MergeType mergeType = processorConfig.getMergeType();
    switch (mergeType) {
      case CONCAT:
        return new ConcatReducer(fileManager);
      case ROLLUP:
        return new RollupReducer(partitionId, fileManager, processorConfig.getAggregationTypes(), reducerOutputDir);
      case DEDUP:
        return new DedupReducer(partitionId, fileManager, reducerOutputDir);
      default:
        throw new IllegalStateException("Unsupported merge type: " + mergeType);
    }
  }
}

==> apache-pinot-1.4.0-src.tar.gz: apache-pinot-1.4.0-src/pinot-core/src/main/java/org/apache/pinot/core/segment/processing/reducer/ReducerFactory.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pinot.core.segment.processing.reducer;

import java.io.File;
import org.apache.pinot.core.segment.processing.framework.MergeType;
import org.apache.pinot.core.segment.processing.framework.SegmentProcessorConfig;
import org.apache.pinot.core.segment.processing.genericrow.GenericRowFileManager;


/**
 * Factory for Reducer.
 */
public class ReducerFactory {
  private ReducerFactory() {
  }

  public static Reducer getReducer(String partitionId, GenericRowFileManager fileManager,
      SegmentProcessorConfig processorConfig, File reducerOutputDir) {
    MergeType mergeType = processorConfig.getMergeType();
    switch (mergeType) {
      case CONCAT:
        return new ConcatReducer(fileManager);
      case ROLLUP:
        return new RollupReducer(partitionId, fileManager, processorConfig.getAggregationTypes(),
            processorConfig.getAggregationFunctionParameters(), reducerOutputDir);
      case DEDUP:
        return new DedupReducer(partitionId, fileManager, reducerOutputDir);
      default:
        throw new IllegalStateException("Unsupported merge type: " + mergeType);
    }
  }
}
